﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace FisheyeButtons6
{
    public class ScalableContentPresenter : ContentPresenter
    {
        ScaleTransform xform = new ScaleTransform();

        public static readonly DependencyProperty ScaleXProperty =
            DependencyProperty.Register("ScaleX",
                typeof(double),
                typeof(ScalableContentPresenter),
                new PropertyMetadata(1.0, OnScaleChanged));

        public static readonly DependencyProperty ScaleYProperty =
            DependencyProperty.Register("ScaleY",
                typeof(double),
                typeof(ScalableContentPresenter),
                new PropertyMetadata(1.0, OnScaleChanged));

        public ScalableContentPresenter()
        {
            RenderTransform = xform;
        }

        public double ScaleX
        {
            set { SetValue(ScaleXProperty, value); }
            get { return (double)GetValue(ScaleXProperty); }
        }

        public double ScaleY
        {
            set { SetValue(ScaleYProperty, value); }
            get { return (double)GetValue(ScaleYProperty); }
        }

        static void OnScaleChanged(DependencyObject obj, 
                                   DependencyPropertyChangedEventArgs args)
        {
            ScalableContentPresenter scaler = 
                                obj as ScalableContentPresenter;
            scaler.xform.ScaleX = scaler.ScaleX;
            scaler.xform.ScaleY = scaler.ScaleY;
            scaler.InvalidateMeasure();
        }

        protected override Size MeasureOverride(Size availableSize)
        {
            Size desiredSize = base.MeasureOverride(availableSize);
            desiredSize.Width *= ScaleX;
            desiredSize.Height *= ScaleY;
            return desiredSize;
        }
    }
}
